import { useStore } from '@nanostores/preact'
import { useEffect, useState } from 'preact/hooks'
import { triggerCounter } from './store.js'

export const JobLogs = ({ endpoint }) => {
    const $triggerCounter = useStore(triggerCounter)

    const [logLines, setLogLines] = useState([])

    useEffect(async () => {
        const res = await fetch(endpoint + '?format=raw')
        const rawLogs = (await res.text()).trim()

        if (rawLogs.length > 0) setLogLines(rawLogs.split('\n'))
        else setLogLines([])

        // Setup SSE
        const es = new EventSource(endpoint + '?format=sse')
        es.addEventListener('message', ({ data }) => {
            const event = JSON.parse(data)
            setLogLines(lines => [...lines, event.content])
        })
    }, [$triggerCounter])

    // prettier-ignore
    return (
        <pre title={`Triggered ${$triggerCounter} times`}><code>{logLines.join('\n')}</code></pre>
    )
}
